Welcome to the scilpy documentation!
======================================

.. toctree::
    :maxdepth: 1
    :caption: Scilpy

    modules/scilpy
    scripts/modules

.. toctree::
    :maxdepth: 1
    :caption: Documentation and Tutorials

    documentation/btensor_scripts
    documentation/bundle_diameter_fitting_function
    documentation/construct_participants_tsv_file
    documentation/create_overlapping_slice_mosaics
    documentation/devcontainer
    documentation/fibertube_tracking
    documentation/tractogram_registration
